@@ -21,7 +21,6 @@ class DownloadProgressBar(tqdm):
         self.update(b * bsize - self.n)
 
 def notebookYOLO (path):
-    #primero realizamos una copia del fichero en la carpeta de las imagenes
     url = "https://www.dropbox.com/s/9euz1j2eydbeimk/YOLOExampleDDStoma.ipynb?dl=1"
     with DownloadProgressBar(unit='B', unit_scale=True,
                              miniters=1, desc=url.split('/')[-1]) as t:
@@ -46,10 +45,8 @@ def notebookYOLO (path):
 
         lstFiles.sort()
         for fichero in lstFiles:
-            # variables que vamos a necesitar
             doc = etree.parse(path + '/' + fichero)
-            filename = doc.getroot()  # buscamos la raiz de nuestro xml
-            # Listamos todos los objetos que encontremos en nuestro xml
+            filename = doc.getroot()
             objetos = filename.findall("object")
             for objeto in objetos:
                 name = objeto.find("name").text
@@ -63,20 +60,19 @@ def notebookYOLO (path):
         listaCla1 = listaCla[:len(listaCla) - 1]
         listaCla1 = listaCla1 + ']\n'
 
-        # Invocamos a la funcion con dichos parametros y mostramos el resultado por pantalla
         images = list(paths.list_files(path, validExts=(".jpg", ".jpeg", ".png", ".bmp", ".tiff", ".tif", ".xml")))
         os.mkdir(path + '/dataset')  # carpeta
         for i in images:
             shutil.copy(i, path + '/dataset/')
         fichsXml = glob.glob(path + "/dataset/*.xml")
         os.mkdir(path + '/dataset/Anotadas/')
-        for f in fichsXml:  ## copiamos las imagenes que tienen xml y los xml dentro de VOCdataset
+        for f in fichsXml:
             shutil.move(f, path + '/dataset/Anotadas/')
             #shutil.move(path + '/dataset/' + os.path.split(f)[1].split('.')[0] + '.jpg', path + '/dataset/Anotadas/')
             #cadena1 = f.split('.')
             nombreFichero1 = f[0:len(f) - 4]
             shutil.move(nombreFichero1 + '.jpg', path + '/dataset/Anotadas/')
-        #notebooks.pascal2yolo_1class.principal(path+'/dataset/Anotadas/')  # convertimos de xml a txt ya que yolo solo trabaja con txt
+        #notebooks.pascal2yolo_1class.principal(path+'/dataset/Anotadas/')
         #fichsXml2 = glob.glob(path + "/dataset/Anotadas/*.txt")
         #for x in fichsXml2:
             #os.remove(x)
@@ -103,7 +99,6 @@ def notebookYOLO (path):
             f.write(p + '\n')
         f.close()
         generaFicheroData(len(clasesSinRep), path+'/dataset')
-        #modificamos las tecnicas
         #tec = 'myTechniques = ['
         #for p in tecnhiques:
         #    tec = tec+'\''+str(p)+'\','
@@ -123,59 +118,36 @@ def notebookYOLO (path):
 def datasetSplit( Nproyecto, darknetPath, pathImages, porcentaje):
     listaFicheros = list(paths.list_files(pathImages,validExts=(".jpg")))
     train_list,test_list, _ ,_ = train_test_split(listaFicheros, listaFicheros, train_size=porcentaje)
-    #creamos la estructura de carpetas, la primera contendra las imagenes del entrenamiento
     os.makedirs(os.path.join(darknetPath , Nproyecto , 'train', 'JPEGImages'))
-    #esta carpeta contendra las anotaciones de las imagenes de entrenamiento
     os.makedirs(os.path.join(darknetPath , Nproyecto , 'train', 'labels'))
-    #y esta ultima carpeta va a contener tanto las imagenes como los ficheros de anotaciones del test
     os.makedirs(os.path.join(darknetPath , Nproyecto , 'test', 'JPEGImages'))
-    #para las imagenes de entrenamiento
     for file in train_list:
-        #obtenemos el fichero .txt asociado
         ficherolabel = file[0:file.rfind('.')]+'.xml'
-        #obetenemos el nombre de los ficheros
         name = os.path.basename(file).split('.')[0]
-        #movemos las imagenes a la carpeta JpegImages
         shutil.copy(file, os.path.join(darknetPath , Nproyecto , 'train', 'JPEGImages',name+'.jpg'))
-        #movemos las anotaciones a la carpeta
         shutil.copy(ficherolabel,os.path.join(darknetPath , Nproyecto , 'train', 'JPEGImages',name+'.xml'))
-    #para las imagenes de entrenamiento
     for file in test_list:
-        #obtenemos el fichero .txt asociado
         ficherolabel = file[0:file.rfind('.')]+'.xml'
-        #obetenemos el nombre de los ficheros
         name = os.path.basename(file).split('.')[0]
-        #movemos las imagenes a la carpeta JpegImages
         shutil.copy(file, os.path.join(darknetPath , Nproyecto , 'test', 'JPEGImages',name+'.jpg'))
-        #movemos las anotaciones a la carpeta
         shutil.copy(ficherolabel, os.path.join(darknetPath , Nproyecto , 'test', 'JPEGImages',name+'.xml'))
 def generaFicheroTrain(darknetPath):
-    #creamos el fichero train.txt
     f = open (os.path.join(darknetPath,"train.txt"), 'w')
-    #listamos todos los ficheros .jpg del conjunto de entrenamiento
     files = os.listdir(os.path.join(darknetPath, "train/JPEGImages/"))
-    #recorremos la lista e imprimimos una imagen por linea
     for l in files:
         f.write('/content/darknet-colab/dataset/train/JPEGImages/'+l.split('.')[0] +'.jpg'+'\n')
 
 def generaFicheroTest(darknetPath):
-    #creamos el fichero test.txt
     f = open(os.path.join(darknetPath,"test.txt"), 'w')
-    #listamos todos los ficheros .jpg del conjunto de test
     files = os.listdir(os.path.join(darknetPath, "test/JPEGImages/"))
-    #images = list(paths.list_files(darknetPath, validExts=(".jpg", ".jpeg", ".png", ".bmp", ".tiff", ".tif")))
-    #recorremos la lista e imprimimos una imagen por linea
     for l in files:
         start, ext = os.path.splitext(l)
         if ext==('.jpg'):
-            #si es una imagen la guardamos
             f.write('/content/darknet-colab/dataset/test/JPEGImages/'+l.split('.')[0]+'.jpg'+'\n')
 
 
 def generaFicheroData(NClases, Nproyecto):
-    #creamos el fichero
     f = open (os.path.join(Nproyecto +"/classes.data"),'w')
-    #empezamos poniendo el numero de clases
     f.write('classes= ' + str(NClases)+'\n')
     f.write('train  = /content/darknet-colab/dataset/train.txt' +'\n')
     f.write('valid  = /content/darknet-colab/dataset/test.txt' +'\n')
@@ -183,11 +155,8 @@ def generaFicheroData(NClases, Nproyecto):
     f.write('backup = /content/darknet-colab/backup'+'\n')
     f.close()
 
-#funcion que nos genera los ficheros de YOLO
 def generaFicherosYoloTrain(pathProyecto, NClases):
-	#creamos el fichero yolo.cfg con la configuracion correspondiente a YOLO
 	f = open (pathProyecto+"/dataset/train.cfg",'w')
-	#Texto del fichero
 	mensaje = """[net]
 # Testing
 # batch=1
@@ -976,16 +945,13 @@ jitter=.3
 ignore_thresh = .7
 truth_thresh = 1
 random=1"""
-	#escribimos el mensaje en el fichero
 	f.write(mensaje)
 	f.close()
 
 
 
 def generaFicherosYoloTest(pathProyecto,NClases):
-	#creamos el fichero yolo.cfg con la configuracion correspondiente a YOLO
 	f = open (pathProyecto+"/dataset/test.cfg",'w')
-	#Texto del fichero
 	mensaje = """[net]
 # Testing
 batch=1
@@ -1774,7 +1740,6 @@ jitter=.3
 ignore_thresh = .7
 truth_thresh = 1
 random=1"""
-	#escribimos el mensaje en el fichero
 	f.write(mensaje)
 	f.close()
 
